@@ -1148,6 +1148,21 @@ class OperatorTests(unittest.TestCase):
         self.assertIn(d['name'], params.values())
         self.assertIn(d['loc']['city'], params.values())
 
+    def test_can_use_dict_inside_of_list(self):
+        item = 'one'
+        toplevel = 1
+        args = { 'nested': [{'item': item}], 'toplevel': toplevel}
+        p = Pypher()
+        p.SET.UPDATED += args
+        q = str(p)
+        params = p.bound_params
+        exp = ('SET UPDATED += {{`nested`: [{{`item`: ${item}}}], `toplevel`: ${toplevel}}}').format(
+            item=get_dict_key(params, item),
+            toplevel=get_dict_key(params, toplevel))
+
+        self.assertEqual(exp, q)
+        self.assertEqual(2, len(params))
+
 
 class ParamTests(unittest.TestCase):
 
@@ -1320,5 +1335,26 @@ class ParamTests(unittest.TestCase):
         self.assertEqual(exp, s)
         self.assertEqual(1, len(p.bound_params))
 
+    def test_cannot_match_falsy_params_with_false(self):
+        p = Pypher()
+        f = p.bind_param(False)
+        z = p.bind_param(0)
+
+        str(p)
+        params = p.bound_params
+
+        self.assertEqual(2, len(params))
+
+    def test_cannot_match_truthy_params_with_true(self):
+        p = Pypher()
+        f = p.bind_param(True)
+        z = p.bind_param(1)
+
+        str(p)
+        params = p.bound_params
+
+        self.assertEqual(2, len(params))
+
+
 if __name__ == '__main__':
     unittest.main()
